# Supported Data

## Supported Areas

| Code | Name | Description |
|------|------|-------------|
| WLD | World | Global coverage |
| AME | Americas | North and South America |
| EUR | Europe | European continent |
| ASI | Asia | Asian continent |
| OCN | Oceania | Australia, New Zealand, Pacific Islands |
| AFR | Africa | African continent |

## Supported Exchanges

The following exchanges are supported:

```
ADX ALOR AMEX ASX ATHEX BAHRAIN BASESWAP BCBA BCS BELEX
BER BET BINANCE BINANCEUS BINGX BIST BISWAP BITAZZA BITBNS BITCOKE
BITFINEX BITFLYER BITGET BITHUMB BITKUB BITMART BITMEX BITPANDAPRO
BITRUE BITSTAMP BITTREX BITVAVO BIVA BLACKBULL BLOFIN BME BMFBOVESPA BMV BSE BSSE
BTSE BVB BVC BVCV BVL BVMT BX BYBIT CAMELOT CAMELOT3ARBITRUM
CAPITALCOM CBOE CBOT CBOT_MINI CEXIO CFFEX CITYINDEX CME CME_MINI COINBASE
COINEX COMEX COMEX_MINI CRYPTO CRYPTOCAP CRYPTOCOM CSE CSECY CSELK CSEMA
CURRENCYCOM CURVE DELTA DERIBIT DFM DJ DSEBD DUS DYDX EASYMARKETS
ECONOMICS EGX EIGHTCAP EURONEXT EUROTLX EUREX EXMO FINRA FOREXCOM FSE
FTSEMYX FTX FWB FX FX_IDC FXCM FXOPEN GATEIO GEMINI GETTEX
GLOBALPRIME GPW HAM HAN HITBTC HKEX HNX HONEYSWAP HONEYSWAPPOLYGON
HOSE HSI HTX HUOBI ICEAD ICEEUR ICESG ICEUS IDX INDEX
JSE KATANA KRX KRAKEN KSE KUCOIN LS LSE LSIN LSX
LUXSE MATBAROFEX MCX MERCADO MEXC MGEX MIL MMFINANCE MOEX MUN MYX
NAG NASDAQ NASDAQDUBAI NCDEX NEO NEWCONNECT NGM NSE
NSEKE NSENG NYMEX NYMEX_MINI NYSE NZX OANDA OKCOIN OKX OMXCOP
OMXHEX OMXICE OMXRSE OMXSTO OMXTSE OMXVSE ORCA OSE OSL OTC
PANCAKESWAP PANCAKESWAP3BSC PANCAKESWAP3ETH PANGOLIN PEPPERSTONE PHEMEX PHILLIPNOVA PIONEX POLONIEX PSE
PSECZ PSX PULSEX QSE QUICKSWAP QUICKSWAP3POLYGON QUICKSWAP3POLYGONZKEVM RAYDIUM RUS SAPSE
SAXO SET SGX SHFE SIX SKILLING SP SPARKS SPOOKYSWAP SSE
SUSHISWAP SUSHISWAPPOLYGON SWB SZSE TADAWUL TAIFEX TASE TFEX TFX THRUSTER3
TIMEX TOCOM TOKENIZE TPEX TRADEGATE TRADERJOE TRADESTATION TSE TSX TSXV
TVC TWSE UNISWAP UNISWAP3ARBITRUM UNISWAP3AVALANCHE UNISWAP3BASE UNISWAP3BSC UNISWAP3ETH UNISWAP3OPTIMISM
UNISWAP3POLYGON UPBIT UPCOM VANTAGE VELODROME VERSEETH VIE VVSFINANCE WAGYUSWAP WHITEBIT WOONETWORK XETR XEXCHANGE ZOOMEX
```

## Supported Indicators

### Momentum Indicators

| Indicator | Description |
|-----------|-------------|
| RSI | Relative Strength Index |
| RSI[1] | RSI (previous value) |
| Stoch.K | Stochastic %K |
| Stoch.D | Stochastic %D |
| Stoch.K[1] | Stochastic %K (previous) |
| Stoch.D[1] | Stochastic %D (previous) |
| CCI20 | Commodity Channel Index (20-period) |
| CCI20[1] | CCI20 (previous) |
| ADX | Average Directional Index |
| ADX+DI | ADX + Directional Indicator |
| ADX-DI | ADX - Directional Indicator |
| ADX+DI[1] | ADX+DI (previous) |
| ADX-DI[1] | ADX-DI (previous) |
| AO | Awesome Oscillator |
| AO[1] | AO (previous) |
| AO[2] | AO (previous 2) |
| Mom | Momentum |
| Mom[1] | Momentum (previous) |

### Moving Averages

| Indicator | Description |
|-----------|-------------|
| EMA10 | Exponential Moving Average (10) |
| EMA20 | Exponential Moving Average (20) |
| EMA30 | Exponential Moving Average (30) |
| EMA50 | Exponential Moving Average (50) |
| EMA100 | Exponential Moving Average (100) |
| EMA200 | Exponential Moving Average (200) |
| SMA10 | Simple Moving Average (10) |
| SMA20 | Simple Moving Average (20) |
| SMA30 | Simple Moving Average (30) |
| SMA50 | Simple Moving Average (50) |
| SMA100 | Simple Moving Average (100) |
| SMA200 | Simple Moving Average (200) |
| VWMA | Volume Weighted Moving Average |
| HullMA9 | Hull Moving Average (9) |

### MACD Components

| Indicator | Description |
|-----------|-------------|
| MACD.macd | MACD Line |
| MACD.signal | MACD Signal Line |

### Pivot Points

#### Classic
| Indicator | Description |
|-----------|-------------|
| Pivot.M.Classic.S3 | Classic Pivot S3 |
| Pivot.M.Classic.S2 | Classic Pivot S2 |
| Pivot.M.Classic.S1 | Classic Pivot S1 |
| Pivot.M.Classic.Middle | Classic Pivot Middle |
| Pivot.M.Classic.R1 | Classic Pivot R1 |
| Pivot.M.Classic.R2 | Classic Pivot R2 |
| Pivot.M.Classic.R3 | Classic Pivot R3 |

#### Fibonacci
| Indicator | Description |
|-----------|-------------|
| Pivot.M.Fibonacci.S3 | Fibonacci Pivot S3 |
| Pivot.M.Fibonacci.S2 | Fibonacci Pivot S2 |
| Pivot.M.Fibonacci.S1 | Fibonacci Pivot S1 |
| Pivot.M.Fibonacci.Middle | Fibonacci Pivot Middle |
| Pivot.M.Fibonacci.R1 | Fibonacci Pivot R1 |
| Pivot.M.Fibonacci.R2 | Fibonacci Pivot R2 |
| Pivot.M.Fibonacci.R3 | Fibonacci Pivot R3 |

#### Camarilla
| Indicator | Description |
|-----------|-------------|
| Pivot.M.Camarilla.S3 | Camarilla Pivot S3 |
| Pivot.M.Camarilla.S2 | Camarilla Pivot S2 |
| Pivot.M.Camarilla.S1 | Camarilla Pivot S1 |
| Pivot.M.Camarilla.Middle | Camarilla Pivot Middle |
| Pivot.M.Camarilla.R1 | Camarilla Pivot R1 |
| Pivot.M.Camarilla.R2 | Camarilla Pivot R2 |
| Pivot.M.Camarilla.R3 | Camarilla Pivot R3 |

#### Woodie
| Indicator | Description |
|-----------|-------------|
| Pivot.M.Woodie.S3 | Woodie Pivot S3 |
| Pivot.M.Woodie.S2 | Woodie Pivot S2 |
| Pivot.M.Woodie.S1 | Woodie Pivot S1 |
| Pivot.M.Woodie.Middle | Woodie Pivot Middle |
| Pivot.M.Woodie.R1 | Woodie Pivot R1 |
| Pivot.M.Woodie.R2 | Woodie Pivot R2 |
| Pivot.M.Woodie.R3 | Woodie Pivot R3 |

#### DeMark
| Indicator | Description |
|-----------|-------------|
| Pivot.M.Demark.S1 | DeMark Pivot S1 |
| Pivot.M.Demark.Middle | DeMark Pivot Middle |
| Pivot.M.Demark.R1 | DeMark Pivot R1 |

### Recommendation Indicators

| Indicator | Description |
|-----------|-------------|
| Recommend.Other | Other Recommendations |
| Recommend.All | All Recommendations |
| Recommend.MA | Moving Average Recommendations |
| Rec.Stoch.RSI | Stochastic RSI Recommendation |
| Rec.WR | Williams %R Recommendation |
| Rec.BBPower | Bollinger Bands Power Recommendation |
| Rec.UO | Ultimate Oscillator Recommendation |
| Rec.Ichimoku | Ichimoku Recommendation |
| Rec.VWMA | VWMA Recommendation |
| Rec.HullMA9 | Hull MA9 Recommendation |

### Other Indicators

| Indicator | Description |
|-----------|-------------|
| BBPower | Bollinger Bands Power |
| UO | Ultimate Oscillator |
| Ichimoku.BLine | Ichimoku Baseline |
| close | Close Price |
| W.R | Williams %R |
| Stoch.RSI.K | Stochastic RSI %K |

## Supported Languages

| Language | Code |
|----------|------|
| English | en |
| German | de |
| French | fr |
| Spanish | es |
| Italian | it |
| Portuguese | pt |
| Russian | ru |
| Japanese | ja |
| Korean | ko |
| Arabic | ar |
| Hindi | hi |
| Swedish | sv |
| Turkish | tr |
| Thai | th |
| Vietnamese | vi |
| Indonesian | id |
| Persian | fa |
| Chinese | ch |
| Malay | ms |
| Greek | el |
| Hebrew | he |

## Supported News Providers

| Provider | Description |
|----------|-------------|
| the_block | The Block - Crypto news |
| cointelegraph | Cointelegraph - Crypto news |
| beincrypto | BeInCrypto - Crypto news |
| newsbtc | NewsBTC - Crypto news |
| dow-jones | Dow Jones - Financial news |
| cryptonews | CryptoNews - Crypto news |
| coindesk | CoinDesk - Crypto news |
| cryptoglobe | CryptoGlobe - Crypto news |
| tradingview | TradingView - Market analysis |
| zycrypto | ZyCrypto - Crypto news |
| todayq | Todayq - Financial news |
| cryptopotato | CryptoPotato - Crypto news |
| u_today | U.Today - Crypto news |
| cryptobriefing | CryptoBriefing - Crypto news |
| coindar | Coindar - Crypto events |
| bitcoin_com | Bitcoin.com - Crypto news |

## Supported Timeframes

| Timeframe | Code | Description |
|-----------|------|-------------|
| 1m | 1 | 1 minute |
| 5m | 5 | 5 minutes |
| 15m | 15 | 15 minutes |
| 30m | 30 | 30 minutes |
| 1h | 60 | 1 hour |
| 2h | 120 | 2 hours |
| 4h | 240 | 4 hours |
| 1d |  | 1 day |
| 1w | 1W | 1 week |
| 1M | 1M | 1 month |